unit ScaleTestMain;

  interface
    uses
      Chart        (* tChart *),
      Classes      (*  *),
      ComCtrls     (* tDateTimePicker *),
      Controls     (*  *),
      ExtCtrls     (* tLabeledEdit; also used by Chart *),
      Forms        (* tForm *),
      Menus        (* tMainMenu, tMenuItem *),
      ScaleManager (* tBottomDayOffsetScale, tLeftCelsiusScale *),
      Series       (* tLineSeries *),
      StdCtrls     (* tButton, tGroupBox, tLabel *),
      TeEngine     (* used by Chart *),
      TeeProcs     (* used by Chart *),
      Windows;

    type
      tfmScaleTest = class(tForm)
          btnPlot: tButton;
          chartTest: tChart;
            seriesCelsius: tLineSeries;
            seriesData:    tLineSeries;
            seriesDates:   tLineSeries;
          grpDateLimits: tGroupBox;
            dtpAnchor: tDateTimePicker;
            dtpBegin:  tDateTimePicker;
            dtpEnd:    tDateTimePicker;
            lbAnchor: tLabel;
            lbBegin:  tLabel;
            lbEnd:    tLabel;
          grpFahrenheitLimits: tGroupBox;
            lbedMaximum: tLabeledEdit;
            lbedMinimum: tLabeledEdit;
          menuMain: tMainMenu;
            menuGrid: tMenuItem;
          procedure btnPlotClick (Sender: tObject);
          procedure FormDestroy  (Sender: tObject);
          procedure FormShow     (Sender: tObject);
          procedure menuGridClick(Sender: tObject);
        private
          CelsiusScale: tLeftCelsiusScale;
          DayOffsetScale: tBottomDayOffsetScale;
        end (* tfmScaleTest *);

    var
      fmScaleTest: tfmScaleTest;

  implementation
    uses
      SysUtils (* StrToFloat *);
      {$R *.dfm}

    procedure tfmScaleTest.FormDestroy(Sender: TObject);
      (* reclaim storage *)

      begin (* tfmScaleTest.FormDestroy *)
        if assigned(CelsiusScale) then
          begin (* clean up *)
            CelsiusScale.Free;
            CelsiusScale := nil
          end   (* clean up *);
          
        if assigned(DayOffsetScale) then
          begin (* clean up *)
            DayOffsetScale.Free;
            DayOffsetScale := nil
          end   (* clean up *)
      end   (* tfmScaleTest.FormDestroy *);

    procedure tfmScaleTest.FormShow(Sender: tObject);
      (* initialize *)

      begin (* tfmScaleTest.FormShow *)
        if assigned(CelsiusScale) then
          CelsiusScale.Free;
        CelsiusScale   := tLeftCelsiusScale.Create    (chartTest, seriesCelsius);
        btnPlotClick(nil)
      end   (* tfmScaleTest.FormShow *);

    procedure tfmScaleTest.menuGridClick(Sender: tObject);
      (* ScaleManager does all the work *)
    
      begin (* tfmScaleTest.menuGridClick *)
        menuGrid.Caption := CelsiusScale.ToggleGrid
      end   (* tfmScaleTest.menuGridClick *);

  procedure tfmScaleTest.btnPlotClick(Sender: TObject);
    (* use the limits *)
  
    begin (* tfmScaleTest.btnPlotClick *)
      with chartTest do
        begin (* chartTest *)
          LeftAxis.Minimum := StrToFloat(lbedMinimum.Text);
          LeftAxis.Maximum := StrToFloat(lbedMaximum.Text);
          SetIncrement(LeftAxis);
          CelsiusScale.AdjustLimits;

          if assigned(DayOffsetScale) then
            DayOffsetScale.Free;
          DayOffsetScale := tBottomDayOffsetScale.Create(chartTest, seriesDates, dtpAnchor.Date);
          BottomAxis.Minimum := dtpBegin.Date;
          BottomAxis.Maximum := dtpEnd.Date;
          BottomAxis.Increment := 10;
          DayOffsetScale.AdjustLimits
        end   (* chartTest *)
    end   (* tfmScaleTest.btnPlotClick *);

end.
